@@ -163,8 +163,9 @@ class AutoMode(callbacks.Plugin):
                         # We're not in the channel anymore.
                         pass
                 schedule.addEvent(unban, time.time()+period)
-            banmask =conf.supybot.protocols.irc.banmask.makeBanmask(msg.prefix)
-            irc.queueMsg(ircmsgs.ban(channel, banmask))
+            banmasks = conf.supybot.protocols.irc.banmask.makeExtBanmasks(
+                msg.prefix, channel=channel, network=irc.network)
+            irc.queueMsg(ircmsgs.bans(channel, banmasks))
             irc.queueMsg(ircmsgs.kick(channel, msg.nick))
 
         try:
