@@ -1,6 +1,6 @@
 ###
 # Copyright (c) 2002-2005, Jeremiah Fincher
-# Copyright (c) 2010-2021, The Limnoria Contributors
+# Copyright (c) 2010-2021, Valentin Lorentz
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -34,6 +34,7 @@ import time
 import types
 import atexit
 import logging
+import logging.handlers
 import operator
 import textwrap
 import traceback
@@ -125,22 +126,18 @@ class StdoutStreamHandler(logging.StreamHandler):
             logging._releaseLock()
 
 
-class BetterFileHandler(logging.FileHandler):
+class BetterFileHandler(logging.handlers.WatchedFileHandler):
     def emit(self, record):
-        msg = self.format(record)
         try:
-            self.stream.write(msg)
-        except (UnicodeError, TypeError):
             try:
-                self.stream.write(msg.encode("utf8"))
+                super().emit(record)
             except (UnicodeError, TypeError):
-                try:
-                    self.stream.write(msg.encode("utf8").decode('ascii', 'replace'))
-                except (UnicodeError, TypeError):
-                    self.stream.write(repr(msg))
-        self.stream.write(os.linesep)
-        try:
-            self.flush()
+                # the above line took care of calling reopenIfNeeded(), even
+                # if it raised one of these exceptions.
+                msg = self.format(record)
+                self.stream.write(repr(msg))
+                self.stream.write(os.linesep)
+                self.flush()
         except OSError as e:
             if e.args[0] == 28:
                 print('No space left on device, cannot flush log.')
@@ -179,14 +176,18 @@ class ColorizedFormatter(Formatter):
         else:
             return Formatter.format(self, record, *args, **kwargs)
 
-_logDir = conf.supybot.directories.log()
-if not os.path.exists(_logDir):
-    os.mkdir(_logDir, 0o755)
+def _mkDirs():
+    global _logDir, pluginLogDir
+    _logDir = conf.supybot.directories.log()
+    if not os.path.exists(_logDir):
+        os.mkdir(_logDir, 0o755)
 
-pluginLogDir = os.path.join(_logDir, 'plugins')
+    pluginLogDir = os.path.join(_logDir, 'plugins')
 
-if not os.path.exists(pluginLogDir):
-    os.mkdir(pluginLogDir, 0o755)
+    if not os.path.exists(pluginLogDir):
+        os.mkdir(pluginLogDir, 0o755)
+
+_mkDirs()
 
 try:
     messagesLogFilename = os.path.join(_logDir, 'messages.log')
